Attribute VB_Name = "modSettings"
'----------------------------------------------------
'Project     : Teleprompter
'Module      : modSettings
'Created On  : 12-Sep-2005
'Author      : Himanshu
'Purpose     : This module contains the functions for
'              reading and writing the settings to ini file
'              as well as reading and writing the settings
'              to the registry
'----------------------------------------------------


Option Explicit

Private Const SEC_GENERAL As String = "General"
Private Const KEY_BACKCOLOR As String = "BackColor"
Private Const KEY_FORECOLOR As String = "ForeColor"
Private Const KEY_FONTNAME As String = "FontName"
Private Const KEY_FONTBOLD As String = "FontBold"
Private Const KEY_FONTITALIC As String = "FontItalic"
Private Const KEY_FONTSIZE As String = "FontSize"
Private Const KEY_FONTSTRIKETHROUGH As String = "FontStrikethrough"
Private Const KEY_FONTUNDERLINE As String = "FontUnderline"
Private Const KEY_LINECOLOR As String = "LineColor"

'Read settings
Declare Function GetPrivateProfileString Lib "kernel32" Alias _
   "GetPrivateProfileStringA" (ByVal lpApplicationName As String, _
   ByVal lpKeyName As Any, ByVal lpDefault As String, _
   ByVal lpReturnedString As String, ByVal nSize As Long, _
   ByVal lpFileName As String) As Long


'Write settings
Declare Function WritePrivateProfileString Lib "kernel32" Alias _
   "WritePrivateProfileStringA" (ByVal lpApplicationName As String, _
   ByVal lpKeyName As Any, ByVal lpString As Any, _
   ByVal lpFileName As String) As Long

'Registry Setting
Private Function GetSettings(sSection As String, sKey As String, sDefault As String) As String
    Dim sSetting As String
    sSetting = GetSetting(App.ProductName, sSection, sKey)
    If sSetting = "" Then
        SaveSettings sSection, sKey, sDefault
        sSetting = sDefault
    End If
    GetSettings = sSetting
End Function

'Registry Setting
Private Function SaveSettings(sSection As String, sKey As String, sSetting As String)
    SaveSetting App.ProductName, sSection, sKey, sSetting
End Function

'Ini Setting
Public Function GetAppSetting(sSection As String, sSetting As String) As String
    'CODE
    Dim X As Long
    Dim sEntry As String, sDefault As String
    Dim sRetBuf As String, iLenBuf As Integer, sFileName As String
    Dim sValue As String
    
    'Six arguments
    sSection$ = sSection
    sEntry$ = sSetting
    sDefault$ = ""
    sRetBuf$ = String$(256, 0)   '256 null characters
    iLenBuf% = Len(sRetBuf$)
    sFileName$ = App.Path & "\Settings.ini"
    
    'function will return a value of 12 in this case
    X = GetPrivateProfileString(sSection$, sEntry$, _
               sDefault$, sRetBuf$, iLenBuf%, sFileName$)
    
    'sValue$ will contain the string "PACKARD BELL"
    sValue$ = Left$(sRetBuf$, X)
    GetAppSetting = sValue
End Function

'Ini Setting
Public Sub SaveAppSetting(sSection As String, sSetting As String, sValue As String)
    Dim X            As Long
    Dim sEntry       As String
    Dim sString      As String
    Dim sFileName    As String
    
    sSection$ = sSection
    sEntry$ = sSetting
    sString$ = sValue
    sFileName$ = App.Path & "\Settings.ini"
    
    
    X = WritePrivateProfileString(sSection$, sEntry$, sString$, sFileName$)
    
    If X Then
         MsgBox "Setting has been saved"
    Else
         MsgBox "Error saving setting"
    End If
End Sub

Public Function GetAppName() As String
    GetAppName = GetAppSetting("General", "AppName")
End Function

Public Function GetHelpLink() As String
    GetHelpLink = GetAppSetting("General", "HelpLink")
End Function

Public Function GetBackColor() As Long
    GetBackColor = CLng(Val(GetSettings(SEC_GENERAL, KEY_BACKCOLOR, "&HC0FFFF")))
End Function

Public Function GetForeColor() As Long
    GetForeColor = CLng(Val(GetSettings(SEC_GENERAL, KEY_FORECOLOR, "&H80000012&")))
End Function

Public Function GetFontName() As String
    GetFontName = GetSettings(SEC_GENERAL, KEY_FONTNAME, "MS Sans Serif")
End Function

Public Function GetFontBold() As Boolean
    GetFontBold = CBool(GetSettings(SEC_GENERAL, KEY_FONTBOLD, "False"))
End Function

Public Function GetFontItalic() As Boolean
    GetFontItalic = CBool(GetSettings(SEC_GENERAL, KEY_FONTITALIC, "False"))
End Function

Public Function GetFontSize() As Integer
    GetFontSize = Val(GetSettings(SEC_GENERAL, KEY_FONTSIZE, "28"))
End Function

Public Function GetFontStrikethrough() As Boolean
    GetFontStrikethrough = CBool(GetSettings(SEC_GENERAL, KEY_FONTSTRIKETHROUGH, "False"))
End Function

Public Function GetFontUnderline() As Boolean
    GetFontUnderline = CBool(GetSettings(SEC_GENERAL, KEY_FONTUNDERLINE, "False"))
End Function

Public Function GetLineColor() As Long
    GetLineColor = CLng(Val(GetSettings(SEC_GENERAL, KEY_LINECOLOR, "&H0000C000&")))
End Function

Public Function SaveBackColor(sSetting As String)
    SaveSettings SEC_GENERAL, KEY_BACKCOLOR, sSetting
End Function

Public Function SaveForeColor(sSetting As String)
    SaveSettings SEC_GENERAL, KEY_FORECOLOR, sSetting
End Function

Public Function SaveFontName(sSetting As String)
    SaveSettings SEC_GENERAL, KEY_FONTNAME, sSetting
End Function

Public Function SaveFontBold(sSetting As String)
    SaveSettings SEC_GENERAL, KEY_FONTBOLD, sSetting
End Function

Public Function SaveFontItalic(sSetting As String)
    SaveSettings SEC_GENERAL, KEY_FONTITALIC, sSetting
End Function

Public Function SaveFontSize(sSetting As String)
    SaveSettings SEC_GENERAL, KEY_FONTSIZE, sSetting
End Function

Public Function SaveFontStrikethrough(sSetting As String)
    SaveSettings SEC_GENERAL, KEY_FONTSTRIKETHROUGH, sSetting
End Function

Public Function SaveFontUnderline(sSetting As String)
    SaveSettings SEC_GENERAL, KEY_FONTUNDERLINE, sSetting
End Function

Public Function SaveLineColor(sSetting As String)
    SaveSettings SEC_GENERAL, KEY_LINECOLOR, sSetting
End Function
