Attribute VB_Name = "modWheel"
'----------------------------------------------------
'Project     : Teleprompter
'Module      : modWheel
'Created On  : 12-Sep-2005
'Author      : Himanshu
'Purpose     : This module contains the functions
'              used for tracking the mouse wheel
'              for custom scrolling in the Prompter
'----------------------------------------------------

Option Explicit

'Wheel tracking

'=================================
' Constante de GetSystemMetrics
'=================================
Const SM_MOUSEWHEELPRESENT As Long = 75 '   Vrai si molette


Private Declare Function GetSystemMetrics Lib "user32" ( _
    ByVal nIndex As Long _
) As Long


'=================================
' Constantes de messages
'=================================
Const WM_MOUSEWHEEL As Integer = &H20A  '   action sur la molette
Const WM_MOUSEHOVER As Integer = &H2A1
Const WM_MOUSELEAVE As Integer = &H2A3

Const WM_KEYDOWN As Integer = &H100
Const WM_KEYUP As Integer = &H101
Const WM_CHAR As Integer = &H102

'=================================
' Constants Mask for MouseWheelKey
'=================================
Const MK_LBUTTON As Integer = &H1
Const MK_RBUTTON As Integer = &H2
Const MK_MBUTTON As Integer = &H10
Const MK_SHIFT As Integer = &H4
Const MK_CONTROL As Integer = &H8


Private Type POINTAPI
        X As Long
        Y As Long
End Type

Private Type MSG
    hwnd As Long
    message As Long
    wParam As Long
    lParam As Long
    time As Long
    pt As POINTAPI
End Type

Private Declare Function GetMessage Lib "user32" Alias "GetMessageA" ( _
    lpMsg As MSG, _
    ByVal hwnd As Long, _
    ByVal wMsgFilterMin As Long, _
    ByVal wMsgFilterMax As Long _
) As Long

Private Declare Function DispatchMessage Lib "user32" Alias "DispatchMessageA" ( _
    lpMsg As MSG _
) As Long

Private Declare Function TranslateMessage Lib "user32" ( _
    lpMsg As MSG _
) As Long

'==================================================
'   Fonction used for mouse tracking (Win 98)
'==================================================

Private Declare Function TRACKMOUSEEVENT Lib "user32" Alias "TrackMouseEvent" ( _
    lpEventTrack As TRACKMOUSEEVENT _
) As Boolean

Private Type TRACKMOUSEEVENT
    cbSize As Long
    dwFlags As Long
    hwndTrack As Long
    dwHoverTime As Long
End Type


    '======================================
    ' Constants for TrackMouseEvent type
    '======================================
    Const TME_HOVER As Long = &H1
    Const TME_LEAVE As Long = &H2
    Const TME_QUERY As Long = &H40000000
    Const TME_CANCEL As Long = &H80000000
    
    Const HOVER_DEFAULT As Long = &HFFFFFFFF



'==================================================
'   Fonction used for mouse tracking (old school)
'==================================================
Private Declare Function GetCursorPos Lib "user32" ( _
    lpPoint As POINTAPI _
) As Long
    
Private Declare Function WindowFromPoint Lib "user32" ( _
    ByVal X As Long, _
    ByVal Y As Long _
) As Long
     
Private Declare Function GetClassName Lib "user32" Alias "GetClassNameA" ( _
    ByVal hwnd As Long, _
    ByVal lpClassName As String, _
    ByVal nMaxCount As Long _
) As Long


'=================================
' Variables for wheel tracking
'=================================
Public m_blnWheelPresent As Boolean    ' true if mouse Wheel present
Public m_blnWheelTracking As Boolean   ' true while pumping messages
Public m_blnKeepSpinnig As Boolean       ' true = mouse still active away from source

Public m_tMSG As MSG                   ' messages structure

'==================================
' Constants for sample application
'==================================
Const m_sCurOffset As Single = 112      ' middle of cursor picture is 7 pixels away from side
Const m_WheelForward As Long = -1       ' Wheeling 'Down' like to walk down a window = increase value
Const m_WheelBackward As Long = 1       ' Wheeling 'Down'                            = decrease value

'==================================
' Variables for sample application
'==================================
    'picture section
    Dim m_sScaleMultiplier_H As Single
    Dim m_sScaleMax_H As Single
    Dim m_sScaleMin_H As Single
    Dim m_sScaleValue_H As Single
    
    Dim m_sScaleMultiplier_V As Single
    Dim m_sScaleMax_V As Single
    Dim m_sScaleMin_V As Single
    Dim m_sScaleValue_V As Single
    
    'text section
    Dim m_lWalkWay As Long          ' Will be set to your choice m_WheelForward or m_WheelForward in initialise proc
    Dim m_lMutiplier_Small As Long
    Dim m_lMutiplier_Large As Long
    Dim m_lSampleValue As Long


Sub WatchForWheel(hClient As Long, Optional blnWheelAround As Boolean)

Dim i As Integer
Dim lResult As Long
Dim bResult As Boolean
Dim tTrackMouse As TRACKMOUSEEVENT

Dim tMouseCords As POINTAPI
Dim lX As Long, lY As Long  '   mouse coordinates
Dim lCurrentHwnd As Long    '

Dim iDirection As Integer
Dim iKeys As Integer

If IsMissing(blnWheelAround) Then
    m_blnKeepSpinnig = False
Else
    m_blnKeepSpinnig = blnWheelAround
End If


m_blnWheelTracking = True


    '********************************************************
    ' Message pump:
    ' gets all messages and checks for MouseWheel event
    '********************************************************
    Do While m_blnWheelTracking
    
        lResult = GetCursorPos(tMouseCords) ' Get current mouse location
            lX = tMouseCords.X
            lY = tMouseCords.Y
        
        lCurrentHwnd = WindowFromPoint(lX, lY) ' get the window under the mouse from mouse coordinates
        
        If lCurrentHwnd <> hClient Then
            If m_blnKeepSpinnig = False Then      ' Don't stop if true
                m_blnWheelTracking = False      ' We are off the client window
                Exit Do                         ' so we stop tracking
            End If
        End If
        
        lResult = GetMessage(m_tMSG, frmMain.hwnd, 0, 0)
        
        lResult = TranslateMessage(m_tMSG)
        
        Dim bRestrict As Boolean
        bRestrict = False
        
        Select Case m_tMSG.message
            Case WM_MOUSEWHEEL
                '===============================================================
                ' Message is 'Wheel Rolling'
                '===============================================================
                
                Call WheelAction(hClient, m_tMSG.wParam)
                frmMain.txtFocus.SetFocus
            
            Case WM_MOUSELEAVE
                '======================================================
                ' Mouse Leave generated by TRACKMOUSEEVENT
                ' when mouse leaves client if TRACKMOUSEEVENT structure
                ' well filled (not here...)
                '======================================================
                m_blnWheelTracking = False
                
        End Select
        
        DoEvents
        
        If Not bRestrict Then
            '=======================================
            ' on renvoie le message dans le circuit
            ' pour la gestion des vnements
            '=======================================
            lResult = DispatchMessage(m_tMSG)
            DoEvents
        End If
        
    Loop


End Sub

Sub WheelAction(hClient As Long, wParam)
Dim iKey As Integer
Dim iDir As Integer

'===============================================================
' We get wheel direction (left half of wParams)
' and Keys pressed while 'wheeling' (right half of wParams)
'===============================================================
iKey = CInt("&H" & (Right(Hex(wParam), 4)))
iDir = Sgn(wParam \ 32767)
                

Select Case hClient
    Case frmMain.picBack.hwnd
        '========================================================
        ' CtrlKey used to change scroll to be modified:
        ' on => Scroll_H  off => Scroll_V
        '========================================================
        
            '============================
            ' CtrlKey used as multiplier
            '============================
            If iKey And MK_SHIFT Then
                m_sScaleValue_V = m_sScaleValue_V + iDir * m_sScaleMultiplier_V
            Else
                 m_sScaleValue_V = m_sScaleValue_V + iDir
            End If
            
            '============================
            ' Check limits
            '============================
            If m_sScaleValue_V <= m_sScaleMin_V Then m_sScaleValue_V = m_sScaleMin_V
            If m_sScaleValue_V >= m_sScaleMax_V Then m_sScaleValue_V = m_sScaleMax_V
        
            frmMain.Scroll iDir * -1, 200, False
                
End Select


End Sub

Public Sub InitWheel()
    Dim i As Integer

'=================================
' Mouse section : check for wheel
'=================================
    m_blnWheelPresent = GetSystemMetrics(SM_MOUSEWHEELPRESENT)




'================================
' Picture1  PseudoScrolls section
'================================
    
    m_sScaleMultiplier_H = 10
    m_sScaleMax_H = 150
    m_sScaleMin_H = 0
    m_sScaleValue_H = m_sScaleMax_H / 2
    
    m_sScaleMultiplier_V = 10
    m_sScaleMax_V = 100
    m_sScaleMin_V = 0
    m_sScaleValue_V = m_sScaleMax_V / 2

'=========================
' Text1 section
'=========================
    m_lWalkWay = m_WheelForward
    m_lMutiplier_Small = 10
    m_lMutiplier_Large = 100
    m_lSampleValue = 100
    
End Sub
